summaryrefslogtreecommitdiffstats
path: root/lib/Smokeping
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Smokeping')
-rw-r--r--lib/Smokeping/RRDtools.pm2
-rw-r--r--lib/Smokeping/probes/base.pm14
-rw-r--r--lib/Smokeping/probes/passwordchecker.pm2
3 files changed, 9 insertions, 9 deletions
diff --git a/lib/Smokeping/RRDtools.pm b/lib/Smokeping/RRDtools.pm
index 7260cca..3363f55 100644
--- a/lib/Smokeping/RRDtools.pm
+++ b/lib/Smokeping/RRDtools.pm
@@ -4,7 +4,7 @@ package Smokeping::RRDtools;
Smokeping::RRDtools - Tools for RRD file handling
-=head1 SYNOPSYS
+=head1 SYNOPSIS
use Smokeping::RRDtools;
use RRDs;
diff --git a/lib/Smokeping/probes/passwordchecker.pm b/lib/Smokeping/probes/passwordchecker.pm
index 7633eba..d1cc128 100644
--- a/lib/Smokeping/probes/passwordchecker.pm
+++ b/lib/Smokeping/probes/passwordchecker.pm
@@ -31,7 +31,7 @@ for storing passwords and a method for accessing them.
DOC
description => <<DOC,
-${e}head2 synopsys with more detail
+${e}head2 synopsis with more detail
SmokePing main configuration file:
diff --git a/lib/Smokeping/probes/base.pm b/lib/Smokeping/probes/base.pm
index 8cc4def..4ae81b5 100644
--- a/lib/Smokeping/probes/base.pm
+++ b/lib/Smokeping/probes/base.pm
@@ -42,9 +42,9 @@ sub pod {
my $class = shift;
my $pod = "";
my $podhash = $class->pod_hash;
- $podhash->{synopsys} = $class->pod_synopsys;
+ $podhash->{synopsis} = $class->pod_synopsis;
$podhash->{variables} = $class->pod_variables;
- for my $what (qw(name overview synopsys description variables authors notes bugs see_also)) {
+ for my $what (qw(name overview synopsis description variables authors notes bugs see_also)) {
my $contents = $podhash->{$what};
next if not defined $contents or $contents eq "";
$pod .= "=head1 " . uc $what . "\n\n";
@@ -316,7 +316,7 @@ sub _makevars {
return $to;
}
-sub pod_synopsys {
+sub pod_synopsis {
my $class = shift;
my $classname = ref $class||$class;
$classname =~ s/^Smokeping::probes:://;
@@ -329,8 +329,8 @@ sub pod_synopsys {
+$classname
DOC
- $pod .= $class->_pod_synopsys($probevars);
- my $targetpod = $class->_pod_synopsys($targetvars);
+ $pod .= $class->_pod_synopsis($probevars);
+ my $targetpod = $class->_pod_synopsis($targetvars);
$pod .= "\n # The following variables can be overridden in each target section\n$targetpod"
if defined $targetpod and $targetpod ne "";
$pod .= <<DOC;
@@ -353,8 +353,8 @@ DOC
return $pod;
}
-# synopsys for one hash ref
-sub _pod_synopsys {
+# synopsis for one hash ref
+sub _pod_synopsis {
my $class = shift;
my $vars = shift;
my %mandatory;